@@ -6,14 +6,11 @@ import structlog
 from confluent_kafka import Consumer, KafkaError, KafkaException
 from confluent_kafka.avro import AvroConsumer as ConfluentAvroConsumer
 
-from confluent_kafka_helpers.callbacks import (
-    default_error_cb, default_stats_cb, get_callback
-)
-from confluent_kafka_helpers.exceptions import (
-    EndOfPartition, KafkaTransportError
-)
+from confluent_kafka_helpers.callbacks import default_error_cb, default_stats_cb, get_callback
+from confluent_kafka_helpers.exceptions import EndOfPartition, KafkaTransportError
 from confluent_kafka_helpers.message import Message
 from confluent_kafka_helpers.metrics import base_metric, statsd
+from confluent_kafka_helpers.tracing import tags, tracer
 from confluent_kafka_helpers.utils import retry_exception
 
 logger = structlog.get_logger(__name__)
@@ -53,9 +50,7 @@ class AvroConsumer:
 
     DEFAULT_CONFIG = {
         'client.id': socket.gethostname(),
-        'default.topic.config': {
-            'auto.offset.reset': 'earliest'
-        },
+        'default.topic.config': {'auto.offset.reset': 'earliest'},
         'enable.auto.commit': False,
         'fetch.wait.max.ms': 1000,
         'fetch.min.bytes': 10000,
@@ -64,20 +59,18 @@ class AvroConsumer:
     }
 
     def __init__(
-        self, config, get_message: Callable = get_message,
-        error_handler: Callable = default_error_handler
+        self,
+        config,
+        get_message: Callable = get_message,
+        error_handler: Callable = default_error_handler,
     ) -> None:
         stop_on_eof = config.pop('stop_on_eof', False)
         poll_timeout = config.pop('poll_timeout', 0.1)
         self.non_blocking = config.pop('non_blocking', False)
 
         self.config = {**self.DEFAULT_CONFIG, **config}
-        self.config['error_cb'] = get_callback(
-            config.pop('error_cb', None), default_error_cb
-        )
-        self.config['stats_cb'] = get_callback(
-            config.pop('stats_cb', None), default_stats_cb
-        )
+        self.config['error_cb'] = get_callback(config.pop('error_cb', None), default_error_cb)
+        self.config['stats_cb'] = get_callback(config.pop('stats_cb', None), default_stats_cb)
         self.topics = self._get_topics(self.config)
 
         logger.info("Initializing consumer", config=self.config)
@@ -87,8 +80,11 @@ class AvroConsumer:
         self._generator = self._message_generator()
 
         self._get_message = partial(
-            get_message, consumer=self.consumer, error_handler=error_handler,
-            timeout=poll_timeout, stop_on_eof=stop_on_eof
+            get_message,
+            consumer=self.consumer,
+            error_handler=error_handler,
+            timeout=poll_timeout,
+            stop_on_eof=stop_on_eof,
         )
 
     def __getattr__(self, name):
@@ -106,7 +102,7 @@ class AvroConsumer:
     def __enter__(self):
         return self
 
-    def __exit__(self, exc_type, exc_value, tb):
+    def __exit__(self, exc_type, exc_value, exc_tb):
         # the only reason a consumer exits is when an
         # exception is raised.
         #
@@ -126,7 +122,17 @@ class AvroConsumer:
                 continue
 
             statsd.increment(f'{base_metric}.consumer.message.count.total')
-            yield Message(message)
+            message = Message(message)
+
+            with tracer.extract_headers_and_start_span(
+                operation_name='kafka.consumer.consume', headers=message._meta.headers
+            ) as span:
+                span.set_tag(tags.SPAN_KIND, tags.SPAN_KIND_CONSUMER)
+                span.set_tag(tags.MESSAGE_BUS_DESTINATION, message._meta.topic)
+                span.set_tag(tags.MESSAGE_BUS_KEY, message._meta.key)
+                span.set_tag(tags.MESSAGE_BUS_OFFSET, message._meta.offset)
+                span.set_tag(tags.MESSAGE_BUS_PARTITION, message._meta.partition)
+                yield message
 
     def _get_topics(self, config):
         topics = config.pop('topics', None)
@@ -141,6 +147,11 @@ class AvroConsumer:
     def is_auto_commit(self):
         return self.config.get('enable.auto.commit', True)
 
+    def commit(self, *args, **kwargs):
+        with tracer.start_span(operation_name='kafka.consumer.commit') as span:
+            span.set_tag(tags.SPAN_KIND, tags.SPAN_KIND_CONSUMER)
+            self.consumer.commit(*args, **kwargs)
+
 
 class AvroLazyConsumer(ConfluentAvroConsumer):
     """
