@@ -8,7 +8,7 @@ class Config:
         'bootstrap.servers': 'localhost:9092',
         'group.id': 1,
         'schema.registry.url': '1.1.1.1',
-        'topics': 'a'
+        'topics': 'a',
     }
 
     KAFKA_REPOSITORY_LOADER_CONFIG = {
@@ -18,10 +18,10 @@ class Config:
             'bootstrap.servers': 'localhost:9092',
             'group.id': 1,
             'schema.registry.url': '1.1.1.1',
-        }
+        },
     }
 
-    KAFKA_REPOSITORY_PRODUCER_CONFIG = {
+    KAFKA_PRODUCER_CONFIG = {
         'bootstrap.servers': 'localhost:9092',
         'schema.registry.url': 'a',
         'topics': ['c', 'a'],
