@@ -7,7 +7,9 @@ from unittest.mock import Mock
 import pytest
 
 from confluent_kafka_helpers.message import (
-    Message, extract_timestamp_from_message, kafka_timestamp_to_datetime
+    Message,
+    extract_timestamp_from_message,
+    kafka_timestamp_to_datetime,
 )
 
 mock_message = Mock()
@@ -26,8 +28,7 @@ def test_timestamp_and_datetime_extraction():
     and datetime from a kafka message is working correctly
     """
     test_datetime = datetime.datetime(2017, 1, 15)
-    test_timestamp = (test_datetime -
-                      datetime.datetime(1970, 1, 1)).total_seconds() * 1000.0
+    test_timestamp = (test_datetime - datetime.datetime(1970, 1, 1)).total_seconds() * 1000.0
 
     # valid timestamp in the form kafka would send it if SET
     mock_message.timestamp = Mock(return_value=(1, test_timestamp))
@@ -61,8 +62,9 @@ def test_message_object():
     # valid timestamp
     mock_message.timestamp = Mock(
         return_value=(
-            1, (datetime.datetime(2017, 1, 15) -
-                datetime.datetime(1970, 1, 1)).total_seconds() * 1000.0
+            1,
+            (datetime.datetime(2017, 1, 15) - datetime.datetime(1970, 1, 1)).total_seconds()
+            * 1000.0,
         )
     )
 
@@ -120,20 +122,24 @@ def test_timestamp_is_not_available():
     [
         (
             [('foo', b'bar')],
-            {
-                'foo': 'bar'
-            },
+            {'foo': 'bar'},
         ),
         (
             None,
             {},
         ),
         (
-            {
-                'foo': b'bar'
-            },
+            {'foo': b'bar'},
             {},
         ),
+        (
+            [('foo', None)],
+            {'foo': None},
+        ),
+        (
+            [('foo', 1)],
+            {'foo': 1},
+        ),
     ],
 )
 def test_headers(headers, expected_headers):
